require 'capistrano'
require 'slack-notifier'

Capistrano::Configuration.instance(:must_exist).load do

    set :slack_subdomain, ''
    set :slack_token, ''
    set :slack_channel, ''

    namespace :slack do
        desc "Notify"
        task :notify, :roles => :app, :except => { :no_release => true } do
            if slack_token != '' && slack_subdomain != ''
                notifier = Slack::Notifier.new(slack_subdomain, slack_token)

                notifier.channel  = slack_channel
                notifier.username = 'Deploy Bot'

                text = "#{application} - #{stage} succesfully deployed on branch #{branch}"
                attachments = [{
                    fallback: "",
                    #text: "Optional text that should appear within the attachment",
                    #pretext: "Optional text that should appear above the formatted data",
                    color: "good",
                    fields: [
                        {
                            title: "Deployer",
                            value: ENV['USER'] || ENV['USERNAME'] || 'n/a',
                            short: true
                        },
                        {
                            title: "Server",
                            value: "#{domain}",
                            short: true
                        },
                        {
                            title: "Application",
                            value: "#{application}",
                            short: true
                        },
                        {
                            title: "Environment",
                            value: "#{stage}",
                            short: true
                        },
                        {
                            title: "Branch",
                            value: "#{branch}",
                            short: true
                        },
                        {
                            title: "Date",
                            value: Time.now.to_s,
                            short: true
                        },
                    ]
                }]

                notifier.ping text, icon_emoji: ":rocket:", attachments: attachments
            end

        end
    end

    after "deploy", "slack:notify"
end

